/// Root Includes
#include <TROOT.h>
#include <TApplication.h>
#include <TGFrame.h>
#include <TGCanvas.h>
#include <TRootEmbeddedCanvas.h>

/// Local Includes.
#include "SVPDialog.hh"


/**
 ******************************************************************
 *
 * Function Name : SVPDialog constructor
 *
 *******************************************************************
 */
SVPDialog::SVPDialog(const TGWindow *p, UInt_t w, UInt_t h, UInt_t options) :
    TGMainFrame(p, w, h, 0)
{
    Connect("CloseWindow()", "SVPDialog", this, "CloseWindow()");

    // Used to store GUI elements that need to be deleted in the destructor.
    fCleanup = new TList();
    fCleanup->SetOwner();

    AddEmbeddedCanvas();

    this->SetWindowName("SVP Display");

    this->MapSubwindows();
    this->Resize();

    this->MapWindow();
}

/**
 ******************************************************************
 *
 * Function Name : SVPDialog Destructor
 *
 * Description : delete anything that is dynamically allocated.
 *
 *******************************************************************
 */
SVPDialog::~SVPDialog()
{
    fCleanup->Clear();

    delete fCleanup;

    this->DontCallClose();
    this->DeleteWindow();
}
/**
 ******************************************************************
 *
 * Function Name : CloseWindow
 *
 *******************************************************************
 */
void SVPDialog::CloseWindow()
{
    gApplication->Terminate(0);
}

/**
 ******************************************************************
 *
 * Function Name : AddEmbeddedCanvas
 *
 *******************************************************************
 */
void SVPDialog::AddEmbeddedCanvas()
{
    TGLayoutHints *fL3 = new TGLayoutHints(kLHintsBottom | kLHintsExpandX |
                               kLHintsExpandY, 2, 2, 0, 0);

    fGraphicsFrame = new TGHorizontalFrame(this, 60, 20);

    fCleanup->Add(fGraphicsFrame);

    fEmbeddedCanvas = new TRootEmbeddedCanvas(0, fGraphicsFrame, 600, 600);
    fCleanup->Add(fEmbeddedCanvas);


    fL4 = new TGLayoutHints(kLHintsTop | kLHintsLeft | kLHintsExpandX |
                kLHintsExpandY, 5, 5, 5, 5);
    fCleanup->Add(fL4);

    fGraphicsFrame->AddFrame(fEmbeddedCanvas, fL4);

    this->AddFrame(fGraphicsFrame, fL3);

    fEmbeddedCanvas->Resize();
    fGraphicsFrame->Resize();
}
