/// Root includes http://root.cern.ch
#include <TROOT.h>
#include <TRint.h>

/// Local Includes.
#include "SVPDialog.hh"


// Global data made available by this module
static TApplication *theApp;
static SVPDialog *svpd;


/**
******************************************************************
*
* Function Name : Terminate
*
* Description : Deal with errors in a clean way!
*
* Inputs : Signal causing termination. 
*
*******************************************************************
*/ 
static void Terminate (int sig) 
{
   static int i=0;
   // prevent this from getting into a infinite loop of 
   // deaths. 
    i++;
    if (i>1)
        exit(-1);

    // Put any user termination routines here. 
    delete svpd;
    delete theApp;

    if (sig == 0)
        exit (0);
    else
        exit (-1);
}

/**
 ******************************************************************
 *
 * Function Name : Initialize
 *
 * Description : Initialze the process
 *               - Setup traceback utility
 *               - Connect all signals to route through the terminate 
 *                 method
 *******************************************************************
 */
static bool Initialize(void)
{
    svpd = new SVPDialog(gClient->GetRoot(), 1200, 400, 0);
    return true;
}

/**
 ******************************************************************
 *
 * Function Name : main
 *
 *******************************************************************
 */
int main(int argc, char **argv)
{
    // Start up root.
    theApp = new TApplication("App", &argc, argv);

    if (Initialize())
    {
        theApp->Run();
    }
    Terminate(0);
}
